@@ -734,8 +734,8 @@ def cli(
                                             pass
 
                             if forward_count >= 15:
-                                forwards_found = forwards_df.From.count()
-                                value_count = forwards_df["From"].value_counts()
+                                forwards_found = forwards_df.Source.count()
+                                value_count = forwards_df["Source"].value_counts()
                                 df01 = value_count.rename_axis("unique_values").reset_index(
                                     name="counts"
                                 )
@@ -782,7 +782,7 @@ def cli(
                                     + " forwarded messages"
                                 )
 
-                                df02 = forwards_df.From.unique()
+                                df02 = forwards_df.Source.unique()
                                 unique_forwards = len(df02)
 
                                 #print("\n")
@@ -1454,7 +1454,7 @@ def cli(
 
                                 if forwards_check is True:
                                     if forward_count >= 15:
-                                        forwards_found = c_forwards.From.count()
+                                        forwards_found = c_forwards.Source.count()
                                         value_count = c_forwards["Source"].value_counts()
                                         c_f_stats = value_count.rename_axis(
                                             "unique_values"
